# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from ...common.types.base import Base
from ...credentials.types.credential_id import CredentialId
from ...organization_base.types.environment import Environment
from ...organization_webhook_base.types.webhook_filter import WebhookFilter
from ...organization_webhook_base.types.webhook_id import WebhookId

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class OrganizationWebhook(Base):
    id: WebhookId
    fullname: str = pydantic.Field()
    """
    Human friendly slug for this webhook
    """

    environment: Environment = pydantic.Field()
    """
    Environment that the webhook is configured for. Only events associated with this environment will trigger the webhook.
    """

    filters: typing.List[WebhookFilter] = pydantic.Field()
    """
    Specifies which Webhooks to send.
    """

    url: str = pydantic.Field()
    """
    URL that webhooks will be sent to
    """

    credential_id: CredentialId = pydantic.Field()
    """
    Credential contain secret
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AssetsServiceNowDataset(str, enum.Enum):
    BASIC_VER_0 = "basic_v0"

    def visit(self, basic_ver_0: typing.Callable[[], T_Result]) -> T_Result:
        if self is AssetsServiceNowDataset.BASIC_VER_0:
            return basic_ver_0()



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

from ......core.datetime_utils import serialize_datetime
from .external_reference import ExternalReference
from .granular_marking import GranularMarking
from .id import Id
from .marking_definition import MarkingDefinition

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class CommonProperties(pydantic.BaseModel):
    spec_version: typing.Literal["2.1"]
    id: Id = pydantic.Field()
    """
    The id property uniquely identifies this object.
    """

    created_by_ref: typing.Optional[Identity] = pydantic.Field(default=None)
    """
    The created_by_ref property specifies the id property of the identity object that describes the entity that created this object.
    """

    created: dt.datetime = pydantic.Field()
    """
    The created property represents the time at which the object was originally created.
    """

    modified: dt.datetime = pydantic.Field()
    """
    The modified property is only used by STIX Objects that support versioning and represents the time that this particular version of the object was last modified.
    """

    revoked: typing.Optional[bool] = pydantic.Field(default=None)
    """
    The revoked property indicates whether this object has been revoked. If the revoked property is present and set to true, then the object has been revoked.
    """

    labels: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The labels property is an array of strings that are used to categorize this object.
    """

    confidence: typing.Optional[int] = pydantic.Field(default=None)
    """
    The confidence property is an integer from 0 to 100 that represents the confidence that this object is accurate and valid.
    """

    lang: typing.Optional[str] = pydantic.Field(default=None)
    """
    The lang property specifies the language used in the properties of the object.
    """

    external_references: typing.Optional[typing.List[ExternalReference]] = pydantic.Field(default=None)
    """
    The external_references property is an array of external references that are relevant to this object.
    """

    object_marking_refs: typing.Optional[typing.List[MarkingDefinition]] = pydantic.Field(default=None)
    """
    The object_marking_refs property is an array of ids of marking_definition objects that apply to this object.
    """

    granular_markings: typing.Optional[typing.List[GranularMarking]] = pydantic.Field(default=None)
    """
    The granular_markings property is an array of granular markings that are applied to this object.
    """

    extensions: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    The extensions property is an object that contains custom properties or objects that extend the object.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


from .identity import Identity  # noqa: E402

CommonProperties.update_forward_refs()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..........core.datetime_utils import serialize_datetime
from .timespan_type_id import TimespanTypeId

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class Timespan(pydantic.BaseModel):
    """
    The Time Span object represents different time period durations. If a timespan is fractional, i.e. crosses one period, e.g. a week and 3 days, more than one may be populated since each member is of integral type. In that case <code>type_id</code> if present should be set to <code>Other</code>.
    """

    duration: typing.Optional[int] = pydantic.Field(default=None)
    """
    The duration of the time span in milliseconds.
    """

    duration_days: typing.Optional[int] = pydantic.Field(default=None)
    """
    The duration of the time span in days.
    """

    duration_hours: typing.Optional[int] = pydantic.Field(default=None)
    """
    The duration of the time span in hours.
    """

    duration_mins: typing.Optional[int] = pydantic.Field(default=None)
    """
    The duration of the time span in minutes.
    """

    duration_months: typing.Optional[int] = pydantic.Field(default=None)
    """
    The duration of the time span in months.
    """

    duration_secs: typing.Optional[int] = pydantic.Field(default=None)
    """
    The duration of the time span in seconds.
    """

    duration_weeks: typing.Optional[int] = pydantic.Field(default=None)
    """
    The duration of the time span in weeks.
    """

    duration_years: typing.Optional[int] = pydantic.Field(default=None)
    """
    The duration of the time span in years.
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The type of time span duration the object represents.
    """

    type_id: typing.Optional[TimespanTypeId] = pydantic.Field(default=None)
    """
    The normalized identifier for the time span duration type.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .....v_1_4_0.resources.cloudresourcesinventoryinfo.resources.classes.types.cloud_resources_inventory_info import (
    CloudResourcesInventoryInfo as resources_ocsf_resources_v_1_4_0_resources_cloudresourcesinventoryinfo_resources_classes_types_cloud_resources_inventory_info_CloudResourcesInventoryInfo,
)

CloudResourcesInventoryInfo = resources_ocsf_resources_v_1_4_0_resources_cloudresourcesinventoryinfo_resources_classes_types_cloud_resources_inventory_info_CloudResourcesInventoryInfo



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..........core.datetime_utils import serialize_datetime
from .group import Group
from .request import Request
from .response import Response
from .service import Service

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class Api(pydantic.BaseModel):
    """
    The API, or Application Programming Interface, object represents information pertaining to an API request and response.
    """

    group: typing.Optional[Group] = pydantic.Field(default=None)
    """
    The information pertaining to the API group.
    """

    operation: str = pydantic.Field()
    """
    Verb/Operation associated with the request
    """

    request: typing.Optional[Request] = pydantic.Field(default=None)
    """
    Details pertaining to the API request.
    """

    response: typing.Optional[Response] = pydantic.Field(default=None)
    """
    Details pertaining to the API response.
    """

    service: typing.Optional[Service] = pydantic.Field(default=None)
    """
    The information pertaining to the API service.
    """

    version: typing.Optional[str] = pydantic.Field(default=None)
    """
    The version of the API service.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from .parameter_location import ParameterLocation

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class ProblematicParameter(pydantic.BaseModel):
    id: str = pydantic.Field()
    """
    If the `location` of the parameter is `body`, this value is always a JSON Pointer, otherwise it's the name of the parameter.
    """

    location: ParameterLocation = pydantic.Field()
    """
    The location of the parameter. Possible values are `query`, `header`, `path` or `body`.
    """

    value: typing.Optional[typing.Any] = pydantic.Field(default=None)
    """
    The given value of the parameter.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from ...common.types.base import Base
from ...ticketing.types.priority import Priority
from .notification_id import NotificationId
from .notification_status import NotificationStatus

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class Notification(Base):
    """
    Notification object
    """

    id: NotificationId
    summary: str = pydantic.Field()
    """
    Notification summary.
    """

    priority: typing.Optional[Priority] = pydantic.Field(default=None)
    """
    Notification priority
    """

    notification_status: typing.Optional[NotificationStatus] = pydantic.Field(default=None)
    """
    Notification status
    """

    project: typing.Optional[str] = pydantic.Field(default=None)
    """
    Notification project
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    The current status of the notification.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Notification description.
    """

    issue_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The notification's type.
    """

    creator: typing.Optional[str] = pydantic.Field(default=None)
    """
    The user who created this notification.
    """

    assignee: typing.Optional[str] = pydantic.Field(default=None)
    """
    Who notification is assigned to.
    """

    contact: typing.Optional[str] = pydantic.Field(default=None)
    """
    The notification contact information.
    """

    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Associate tags with Notification
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .types import (
    Connector,
    ConnectorOrId,
    FilterOperation,
    FilterType,
    GetProviderCapabilitiesExpandOptions,
    ListConnectorCapabilitiesExpandOptions,
    ListConnectorsCapabilitiesResponse,
    ListProviderCapabilitiesExpandOptions,
    ListProvidersCapabilitiesResponse,
    ProviderAvailability,
    ProviderCapabilities,
    ProviderCapabilitiesResponse,
    ProviderEnvironment,
    ProviderFilter,
    ProviderOperations,
    ProviderRelease,
    RequestBody,
)

__all__ = [
    "Connector",
    "ConnectorOrId",
    "FilterOperation",
    "FilterType",
    "GetProviderCapabilitiesExpandOptions",
    "ListConnectorCapabilitiesExpandOptions",
    "ListConnectorsCapabilitiesResponse",
    "ListProviderCapabilitiesExpandOptions",
    "ListProvidersCapabilitiesResponse",
    "ProviderAvailability",
    "ProviderCapabilities",
    "ProviderCapabilitiesResponse",
    "ProviderEnvironment",
    "ProviderFilter",
    "ProviderOperations",
    "ProviderRelease",
    "RequestBody",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MappingDataType(str, enum.Enum):
    STRING = "string"
    NUMBER = "number"
    DATETIME = "datetime"
    BOOLEAN = "boolean"
    ARRAY = "array"
    ANY = "any"

    def visit(
        self,
        string: typing.Callable[[], T_Result],
        number: typing.Callable[[], T_Result],
        datetime: typing.Callable[[], T_Result],
        boolean: typing.Callable[[], T_Result],
        array: typing.Callable[[], T_Result],
        any: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is MappingDataType.STRING:
            return string()
        if self is MappingDataType.NUMBER:
            return number()
        if self is MappingDataType.DATETIME:
            return datetime()
        if self is MappingDataType.BOOLEAN:
            return boolean()
        if self is MappingDataType.ARRAY:
            return array()
        if self is MappingDataType.ANY:
            return any()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from ...common.types.id import Id
from ...engine.types.object import Object
from .actor import Actor

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class EscalationPolicyRule(pydantic.BaseModel):
    """
    The escalation policy rule object describes a rule for an escalation policy. It contains an optional id for the rule, a delay in seconds before the next actor is notified, and a list of actors.
    """

    id: typing.Optional[Id] = None
    delay_seconds: int
    actors: typing.List[Actor]
    unmapped: typing.Optional[Object] = pydantic.Field(default=None)
    """
    The attributes that are not mapped to the comment schema. The names and values of those attributes are specific to the provider.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..........core.datetime_utils import serialize_datetime
from ...base.types.url_string import UrlString
from .auth_factor import AuthFactor
from .fingerprint import Fingerprint
from .idp_state_id import IdpStateId
from .scim import Scim
from .sso import Sso

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class Idp(pydantic.BaseModel):
    """
    The Identity Provider object contains detailed information about a provider responsible for creating, maintaining, and managing identity information while offering authentication services to applications. An Identity Provider (IdP) serves as a trusted authority that verifies the identity of users and issues authentication tokens or assertions to enable secure access to applications or services.
    """

    auth_factors: typing.Optional[typing.List[AuthFactor]] = pydantic.Field(default=None)
    """
    The Authentication Factors object describes the different types of Multi-Factor Authentication (MFA) methods and/or devices supported by the Identity Provider.
    """

    domain: typing.Optional[str] = pydantic.Field(default=None)
    """
    The primary domain associated with the Identity Provider.
    """

    fingerprint: typing.Optional[Fingerprint] = pydantic.Field(default=None)
    """
    The fingerprint of the X.509 certificate used by the Identity Provider.
    """

    has_mfa: typing.Optional[bool] = pydantic.Field(default=None)
    """
    The Identity Provider enforces Multi Factor Authentication (MFA).
    """

    issuer: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique identifier (often a URL) used by the Identity Provider as its issuer.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the Identity Provider.
    """

    protocol_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The supported protocol of the Identity Provider. E.g., <code>SAML</code>, <code>OIDC</code>, or <code>OAuth2</code>.
    """

    scim: typing.Optional[Scim] = pydantic.Field(default=None)
    """
    The System for Cross-domain Identity Management (SCIM) resource object provides a structured set of attributes related to SCIM protocols used for identity provisioning and management across cloud-based platforms. It standardizes user and group provisioning details, enabling identity synchronization and lifecycle management with compatible Identity Providers (IdPs) and applications. SCIM is defined in <a target='_blank' href='https://datatracker.ietf.org/doc/html/rfc7643'>RFC-7634</a>
    """

    sso: typing.Optional[Sso] = pydantic.Field(default=None)
    """
    The Single Sign-On (SSO) object provides a structure for normalizing SSO attributes, configuration, and/or settings from Identity Providers.
    """

    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    The configuration state of the Identity Provider, normalized to the caption of the <code>state_id</code> value. In the case of <code>Other</code>, it is defined by the event source.
    """

    state_id: typing.Optional[IdpStateId] = pydantic.Field(default=None)
    """
    The normalized state ID of the Identity Provider to reflect its configuration or activation status.
    """

    tenant_uid: typing.Optional[str] = pydantic.Field(default=None)
    """
    The tenant ID associated with the Identity Provider.
    """

    uid: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique identifier of the Identity Provider.
    """

    url_string: typing.Optional[UrlString] = pydantic.Field(default=None)
    """
    The URL for accessing the configuration or metadata of the Identity Provider.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MalwareTypeOv(str, enum.Enum):
    ADWARE = "adware"
    BACKDOOR = "backdoor"
    BOT = "bot"
    BOOTKIT = "bootkit"
    DDOS = "ddos"
    DOWNLOADER = "downloader"
    DROPPER = "dropper"
    EXPLOIT_KIT = "exploit_kit"
    KEYLOGGER = "keylogger"
    RANSOMWARE = "ransomware"
    REMOTE_ACCESS_TROJAN = "remote_access_trojan"
    RESOURCE_EXPLOITATION = "resource_exploitation"
    ROGUE_SECURITY_SOFTWARE = "rogue_security_software"
    ROOTKIT = "rootkit"
    SCREEN_CAPTURE = "screen_capture"
    SPYWARE = "spyware"
    TROJAN = "trojan"
    VIRUS = "virus"
    WIPER = "wiper"
    WORM = "worm"
    UNKNOWN = "unknown"
    OTHER = "other"

    def visit(
        self,
        adware: typing.Callable[[], T_Result],
        backdoor: typing.Callable[[], T_Result],
        bot: typing.Callable[[], T_Result],
        bootkit: typing.Callable[[], T_Result],
        ddos: typing.Callable[[], T_Result],
        downloader: typing.Callable[[], T_Result],
        dropper: typing.Callable[[], T_Result],
        exploit_kit: typing.Callable[[], T_Result],
        keylogger: typing.Callable[[], T_Result],
        ransomware: typing.Callable[[], T_Result],
        remote_access_trojan: typing.Callable[[], T_Result],
        resource_exploitation: typing.Callable[[], T_Result],
        rogue_security_software: typing.Callable[[], T_Result],
        rootkit: typing.Callable[[], T_Result],
        screen_capture: typing.Callable[[], T_Result],
        spyware: typing.Callable[[], T_Result],
        trojan: typing.Callable[[], T_Result],
        virus: typing.Callable[[], T_Result],
        wiper: typing.Callable[[], T_Result],
        worm: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is MalwareTypeOv.ADWARE:
            return adware()
        if self is MalwareTypeOv.BACKDOOR:
            return backdoor()
        if self is MalwareTypeOv.BOT:
            return bot()
        if self is MalwareTypeOv.BOOTKIT:
            return bootkit()
        if self is MalwareTypeOv.DDOS:
            return ddos()
        if self is MalwareTypeOv.DOWNLOADER:
            return downloader()
        if self is MalwareTypeOv.DROPPER:
            return dropper()
        if self is MalwareTypeOv.EXPLOIT_KIT:
            return exploit_kit()
        if self is MalwareTypeOv.KEYLOGGER:
            return keylogger()
        if self is MalwareTypeOv.RANSOMWARE:
            return ransomware()
        if self is MalwareTypeOv.REMOTE_ACCESS_TROJAN:
            return remote_access_trojan()
        if self is MalwareTypeOv.RESOURCE_EXPLOITATION:
            return resource_exploitation()
        if self is MalwareTypeOv.ROGUE_SECURITY_SOFTWARE:
            return rogue_security_software()
        if self is MalwareTypeOv.ROOTKIT:
            return rootkit()
        if self is MalwareTypeOv.SCREEN_CAPTURE:
            return screen_capture()
        if self is MalwareTypeOv.SPYWARE:
            return spyware()
        if self is MalwareTypeOv.TROJAN:
            return trojan()
        if self is MalwareTypeOv.VIRUS:
            return virus()
        if self is MalwareTypeOv.WIPER:
            return wiper()
        if self is MalwareTypeOv.WORM:
            return worm()
        if self is MalwareTypeOv.UNKNOWN:
            return unknown()
        if self is MalwareTypeOv.OTHER:
            return other()



# This file was auto-generated by Fern from our API Definition.

from .types import AdditionalMapping, MappingChain, MappingDataType

__all__ = ["AdditionalMapping", "MappingChain", "MappingDataType"]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from .patch_op import PatchOp

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class PatchOperation(pydantic.BaseModel):
    """
    JSON patch to apply. A JSON patch is a list of patch operations. (see https://jsonpatch.com/)
    """

    op: PatchOp = pydantic.Field()
    """
    The operation to perform. Supported values are `add`, `copy`, `move`, `replace`, `remove`, and `test`.
    """

    path: str = pydantic.Field()
    """
    The path to the field to update. The path is a JSON Pointer.
    """

    from_: typing.Optional[str] = pydantic.Field(alias="from", default=None)
    """
    The path to the field to copy from. This is required for `copy` and `move` operations.
    """

    value: typing.Optional[typing.Any] = pydantic.Field(default=None)
    """
    The value to set the field to. This is required for `add`, `replace` and `test` operations.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.apiactivity.resources.classes.types.api_activity import (
    ApiActivity as resources_ocsf_resources_v_1_3_0_resources_apiactivity_resources_classes_types_api_activity_ApiActivity,
)

ApiActivity = resources_ocsf_resources_v_1_3_0_resources_apiactivity_resources_classes_types_api_activity_ApiActivity



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MalwareCapabilitiesOv(str, enum.Enum):
    ACCESSES_REMOTE_MACHINES = "accesses_remote_machines"
    ANTI_DEBUGGING = "anti_debugging"
    ANTI_DISASSEMBLY = "anti_disassembly"
    ANTI_EMULATION = "anti_emulation"
    ANTI_MEMORY_FORENSICS = "anti_memory_forensics"
    ANTI_SANDBOX = "anti_sandbox"
    ANTI_VM = "anti_vm"
    CAPTURES_INPUT_PERIPHERALS = "captures_input_peripherals"
    CAPTURES_OUTPUT_PERIPHERALS = "captures_output_peripherals"
    CAPTURES_SYSTEM_STATE_DATA = "captures_system_state_data"
    CAPTURES_TRACES_OF_INFECTION = "captures_traces_of_infection"
    COMMITS_FRAUD = "commits_fraud"
    COMMUNICATES_WITH_C_2 = "communicates_with_c2"
    COMPROMISES_DATA_AVAILABILITY = "compromises_data_availability"
    COMPROMISES_DATA_INTEGRITY = "compromises_data_integrity"
    COMPROMISES_SYSTEM_AVAILABILITY = "compromises_system_availability"
    CONTROLS_LOCAL_MACHINE = "controls_local_machine"
    DEGRADES_SECURITY_SOFTWARE = "degrades_security_software"
    DEGRADES_UPDATES = "degrades_updates"
    DETERMINES_C_2_SERVER = "determines_c2_server"
    EMAILS_SPAM = "emails_spam"
    ESCALATES_PRIVILEGES = "escalates_privileges"
    EVADES_AV = "evades_av"
    EXFILTRATES_DATA = "exfiltrates_data"
    FINGERPRINTS_HOST = "fingerprints_host"
    HIDES_ARTIFACTS = "hides_artifacts"
    HIDES_EXECUTING_CODE = "hides_executing_code"
    INFECTS_FILES = "infects_files"
    INFECTS_REMOTE_MACHINES = "infects_remote_machines"
    INSTALLS_OTHER_COMPONENTS = "installs_other_components"
    PERSISTS_AFTER_SYSTEM_REBOOT = "persists_after_system_reboot"
    PREVENTS_ARTIFACT_ACCESS = "prevents_artifact_access"
    PREVENTS_ARTIFACT_DELETION = "prevents_artifact_deletion"
    PROBES_NETWORK_ENVIRONMENT = "probes_network_environment"
    SELF_MODIFIES = "self_modifies"
    STEALS_AUTHENTICATION_CREDENTIALS = "steals_authentication_credentials"
    VIOLATES_SYSTEM_OPERATIONAL_INTEGRITY = "violates_system_operational_integrity"

    def visit(
        self,
        accesses_remote_machines: typing.Callable[[], T_Result],
        anti_debugging: typing.Callable[[], T_Result],
        anti_disassembly: typing.Callable[[], T_Result],
        anti_emulation: typing.Callable[[], T_Result],
        anti_memory_forensics: typing.Callable[[], T_Result],
        anti_sandbox: typing.Callable[[], T_Result],
        anti_vm: typing.Callable[[], T_Result],
        captures_input_peripherals: typing.Callable[[], T_Result],
        captures_output_peripherals: typing.Callable[[], T_Result],
        captures_system_state_data: typing.Callable[[], T_Result],
        captures_traces_of_infection: typing.Callable[[], T_Result],
        commits_fraud: typing.Callable[[], T_Result],
        communicates_with_c_2: typing.Callable[[], T_Result],
        compromises_data_availability: typing.Callable[[], T_Result],
        compromises_data_integrity: typing.Callable[[], T_Result],
        compromises_system_availability: typing.Callable[[], T_Result],
        controls_local_machine: typing.Callable[[], T_Result],
        degrades_security_software: typing.Callable[[], T_Result],
        degrades_updates: typing.Callable[[], T_Result],
        determines_c_2_server: typing.Callable[[], T_Result],
        emails_spam: typing.Callable[[], T_Result],
        escalates_privileges: typing.Callable[[], T_Result],
        evades_av: typing.Callable[[], T_Result],
        exfiltrates_data: typing.Callable[[], T_Result],
        fingerprints_host: typing.Callable[[], T_Result],
        hides_artifacts: typing.Callable[[], T_Result],
        hides_executing_code: typing.Callable[[], T_Result],
        infects_files: typing.Callable[[], T_Result],
        infects_remote_machines: typing.Callable[[], T_Result],
        installs_other_components: typing.Callable[[], T_Result],
        persists_after_system_reboot: typing.Callable[[], T_Result],
        prevents_artifact_access: typing.Callable[[], T_Result],
        prevents_artifact_deletion: typing.Callable[[], T_Result],
        probes_network_environment: typing.Callable[[], T_Result],
        self_modifies: typing.Callable[[], T_Result],
        steals_authentication_credentials: typing.Callable[[], T_Result],
        violates_system_operational_integrity: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is MalwareCapabilitiesOv.ACCESSES_REMOTE_MACHINES:
            return accesses_remote_machines()
        if self is MalwareCapabilitiesOv.ANTI_DEBUGGING:
            return anti_debugging()
        if self is MalwareCapabilitiesOv.ANTI_DISASSEMBLY:
            return anti_disassembly()
        if self is MalwareCapabilitiesOv.ANTI_EMULATION:
            return anti_emulation()
        if self is MalwareCapabilitiesOv.ANTI_MEMORY_FORENSICS:
            return anti_memory_forensics()
        if self is MalwareCapabilitiesOv.ANTI_SANDBOX:
            return anti_sandbox()
        if self is MalwareCapabilitiesOv.ANTI_VM:
            return anti_vm()
        if self is MalwareCapabilitiesOv.CAPTURES_INPUT_PERIPHERALS:
            return captures_input_peripherals()
        if self is MalwareCapabilitiesOv.CAPTURES_OUTPUT_PERIPHERALS:
            return captures_output_peripherals()
        if self is MalwareCapabilitiesOv.CAPTURES_SYSTEM_STATE_DATA:
            return captures_system_state_data()
        if self is MalwareCapabilitiesOv.CAPTURES_TRACES_OF_INFECTION:
            return captures_traces_of_infection()
        if self is MalwareCapabilitiesOv.COMMITS_FRAUD:
            return commits_fraud()
        if self is MalwareCapabilitiesOv.COMMUNICATES_WITH_C_2:
            return communicates_with_c_2()
        if self is MalwareCapabilitiesOv.COMPROMISES_DATA_AVAILABILITY:
            return compromises_data_availability()
        if self is MalwareCapabilitiesOv.COMPROMISES_DATA_INTEGRITY:
            return compromises_data_integrity()
        if self is MalwareCapabilitiesOv.COMPROMISES_SYSTEM_AVAILABILITY:
            return compromises_system_availability()
        if self is MalwareCapabilitiesOv.CONTROLS_LOCAL_MACHINE:
            return controls_local_machine()
        if self is MalwareCapabilitiesOv.DEGRADES_SECURITY_SOFTWARE:
            return degrades_security_software()
        if self is MalwareCapabilitiesOv.DEGRADES_UPDATES:
            return degrades_updates()
        if self is MalwareCapabilitiesOv.DETERMINES_C_2_SERVER:
            return determines_c_2_server()
        if self is MalwareCapabilitiesOv.EMAILS_SPAM:
            return emails_spam()
        if self is MalwareCapabilitiesOv.ESCALATES_PRIVILEGES:
            return escalates_privileges()
        if self is MalwareCapabilitiesOv.EVADES_AV:
            return evades_av()
        if self is MalwareCapabilitiesOv.EXFILTRATES_DATA:
            return exfiltrates_data()
        if self is MalwareCapabilitiesOv.FINGERPRINTS_HOST:
            return fingerprints_host()
        if self is MalwareCapabilitiesOv.HIDES_ARTIFACTS:
            return hides_artifacts()
        if self is MalwareCapabilitiesOv.HIDES_EXECUTING_CODE:
            return hides_executing_code()
        if self is MalwareCapabilitiesOv.INFECTS_FILES:
            return infects_files()
        if self is MalwareCapabilitiesOv.INFECTS_REMOTE_MACHINES:
            return infects_remote_machines()
        if self is MalwareCapabilitiesOv.INSTALLS_OTHER_COMPONENTS:
            return installs_other_components()
        if self is MalwareCapabilitiesOv.PERSISTS_AFTER_SYSTEM_REBOOT:
            return persists_after_system_reboot()
        if self is MalwareCapabilitiesOv.PREVENTS_ARTIFACT_ACCESS:
            return prevents_artifact_access()
        if self is MalwareCapabilitiesOv.PREVENTS_ARTIFACT_DELETION:
            return prevents_artifact_deletion()
        if self is MalwareCapabilitiesOv.PROBES_NETWORK_ENVIRONMENT:
            return probes_network_environment()
        if self is MalwareCapabilitiesOv.SELF_MODIFIES:
            return self_modifies()
        if self is MalwareCapabilitiesOv.STEALS_AUTHENTICATION_CREDENTIALS:
            return steals_authentication_credentials()
        if self is MalwareCapabilitiesOv.VIOLATES_SYSTEM_OPERATIONAL_INTEGRITY:
            return violates_system_operational_integrity()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from .slack_webhook_credential import SlackWebhookCredential

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class NotificationsSlackWebhook(pydantic.BaseModel):
    """
    Configuration for the Slack Notification Provider using Incoming Webhooks.
    Incoming Webhooks are a way to post messages from apps into Slack. The can not be used for any other actions, such as reading or deleting messages.
    """

    webhook_url: SlackWebhookCredential

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from ...engine.types.object import Object
from .integration_web_hook_id import IntegrationWebHookId

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class IntegrationWebHook(pydantic.BaseModel):
    """
    Integration webhook
    """

    id: IntegrationWebHookId
    creator: str = pydantic.Field()
    """
    The user who created the webHook.
    """

    enabled: bool = pydantic.Field()
    """
    Status of the WebHook.
    """

    events: typing.List[str] = pydantic.Field()
    """
    List of events that trigger the WebHook.
    """

    name: str = pydantic.Field()
    """
    A name for the WebHook.
    """

    value: str = pydantic.Field()
    """
    The content of the webHook, this can be a URL or a specific code, it depends on the provider.
    """

    created_at: dt.datetime = pydantic.Field()
    """
    The date the WebHook was created.
    """

    updated_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The date the WebHook was last updated.
    """

    unmapped: typing.Optional[Object] = pydantic.Field(default=None)
    """
    The attributes that are not mapped to the WebHook schema. The names and values of those attributes are specific to the provider.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class QueryEventStatus(str, enum.Enum):
    PENDING = "PENDING"
    """
    [deprecated] use `QueryStatusPending` instead
    """

    COMPLETE = "COMPLETE"
    """
    [deprecated] use `QueryStatusComplete` instead
    """

    def visit(self, pending: typing.Callable[[], T_Result], complete: typing.Callable[[], T_Result]) -> T_Result:
        if self is QueryEventStatus.PENDING:
            return pending()
        if self is QueryEventStatus.COMPLETE:
            return complete()



# This file was auto-generated by Fern from our API Definition.

from .types import (
    GetGroupMembersResponse,
    GetGroupMembersResponseGeneric,
    GetGroupResponse,
    GetGroupResponseGeneric,
    GetUserResponse,
    GetUserResponseGeneric,
    GroupId,
    QueryGroupsResponse,
    QueryGroupsResponseGeneric,
    QueryIdentityAuditLogResponse,
    QueryIdentityAuditLogResponseGeneric,
    QueryUsersResponse,
    QueryUsersResponseGeneric,
    UserId,
)

__all__ = [
    "GetGroupMembersResponse",
    "GetGroupMembersResponseGeneric",
    "GetGroupResponse",
    "GetGroupResponseGeneric",
    "GetUserResponse",
    "GetUserResponseGeneric",
    "GroupId",
    "QueryGroupsResponse",
    "QueryGroupsResponseGeneric",
    "QueryIdentityAuditLogResponse",
    "QueryIdentityAuditLogResponseGeneric",
    "QueryUsersResponse",
    "QueryUsersResponseGeneric",
    "UserId",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from .crowd_strike_credential import CrowdStrikeCredential
from .crowdstrike_hec_credential import CrowdstrikeHecCredential

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class SiemCrowdstrike(pydantic.BaseModel):
    """
    Configuration for CrowdStrike Falcon® Next-Gen SIEM.

    [Configuration guide](https://docs.synqly.com/guides/provider-configuration/crowdstrike-siem-setup)
    """

    credential: CrowdStrikeCredential = pydantic.Field()
    """
    The credential to use for the CrowdStrike Falcon NextGen SIEM tenant.
    """

    hec_credential: typing.Optional[CrowdstrikeHecCredential] = pydantic.Field(default=None)
    """
    Token credential to use for connecting to the CrowdStrike HEC service. If not provided, sending events to CrowdStrike is disabled.
    """

    hec_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    The generated CrowdStrike HEC URL provided with your token.
    """

    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Base URL for the CrowdStrike Falcon® Next-Gen SIEM API.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from ...member_base.types.create_member_request import CreateMemberRequest

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class CreateOrganizationRequest(pydantic.BaseModel):
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique short name for this Organization (lowercase [a-z0-9_-], can be used in URLs). Used for case insensitive duplicate name detection and default sort order. Defaults to OrganizationId if both name and fullname are not specified.
    """

    fullname: typing.Optional[str] = pydantic.Field(default=None)
    """
    Human friendly display name for this Organization, will auto-generate 'name' field (if 'name' is not specified). Defaults to the same value as the 'name' field if not specified.
    """

    contact: typing.Optional[str] = pydantic.Field(default=None)
    """
    Organization email address
    """

    reply_to: typing.Optional[str] = pydantic.Field(default=None)
    """
    Reply-to email address, used for SMTP emails. Defaults to no-reply@synqly.com
    """

    picture: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL of the organization
    """

    member: typing.Optional[CreateMemberRequest] = pydantic.Field(default=None)
    """
    Create organization member
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from .aws_security_lake_credential import AwsSecurityLakeCredential

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class SinkAwsSecurityLake(pydantic.BaseModel):
    """
    Configuration for Amazon Security Lake as a Sink provider. Events are written directly to an AWS S3 bucket in Apache Parquet format.

    [Configuration guide](https://docs.synqly.com/guides/provider-configuration/amazon-security-lake-sink-setup)
    """

    credential: AwsSecurityLakeCredential = pydantic.Field()
    """
    AWS Access Keys with write access to the configured S3 bucket.
    """

    region: typing.Optional[str] = pydantic.Field(default=None)
    """
    Override the default AWS region for this integration. If not present, the region will be inferred from the URL.
    """

    url: str = pydantic.Field()
    """
    URL of the S3 bucket where the Amazon Security Lake events are stored.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
